package com.flossom.system.service;


import com.flossom.common.core.domain.entity.WxSystemSetting;

import java.util.List;

/**
 * 平台参数设置Service接口
 *
 * @author flossom
 * @date 2023-12-11
 */
public interface IWxSystemSettingService {
    /**
     * 查询平台参数设置
     *
     * @param id 平台参数设置主键
     * @return 平台参数设置
     */
    public WxSystemSetting selectWxSystemSettingById(Long id);

    /**
     * 查询平台参数设置列表
     *
     * @param wxSystemSetting 平台参数设置
     * @return 平台参数设置集合
     */
    public List<WxSystemSetting> selectWxSystemSettingList(WxSystemSetting wxSystemSetting);

    /**
     * 新增平台参数设置
     *
     * @param wxSystemSetting 平台参数设置
     * @return 结果
     */
    public int insertWxSystemSetting(WxSystemSetting wxSystemSetting);

    /**
     * 修改平台参数设置
     *
     * @param wxSystemSetting 平台参数设置
     * @return 结果
     */
    public int updateWxSystemSetting(WxSystemSetting wxSystemSetting);

    /**
     * 批量删除平台参数设置
     *
     * @param ids 需要删除的平台参数设置主键集合
     * @return 结果
     */
    public int deleteWxSystemSettingByIds(Long[] ids);

    /**
     * 删除平台参数设置信息
     *
     * @param id 平台参数设置主键
     * @return 结果
     */
    public int deleteWxSystemSettingById(Long id);
}
